@@ -9,17 +9,21 @@ require "spring/client/stop"
 require "spring/client/status"
 require "spring/client/rails"
 require "spring/client/version"
+require "spring/client/server"
 
 module Spring
   module Client
     COMMANDS = {
       "help"      => Client::Help,
+      "-h"        => Client::Help,
+      "--help"    => Client::Help,
       "binstub"   => Client::Binstub,
       "stop"      => Client::Stop,
       "status"    => Client::Status,
       "rails"     => Client::Rails,
       "-v"        => Client::Version,
-      "--version" => Client::Version
+      "--version" => Client::Version,
+      "server"    => Client::Server,
     }
 
     def self.run(args)
@@ -36,3 +40,9 @@ module Spring
     end
   end
 end
+
+# allow users to add hooks that do not run in the server
+# or modify start/stop
+if File.exist?("config/spring_client.rb")
+  require "./config/spring_client.rb"
+end
