@@ -1,5 +1,5 @@
 require "bundler/setup"
 require "minitest/autorun"
 
-require "spring/test"
+require_relative "support/test"
 Spring::Test.root = File.expand_path('..', __FILE__)
